==> TableDataBundle-Perl-CPAN-Release-20231120.2.tar.gz: TableDataBundle-Perl-CPAN-Release-20231120.2/lib/TableDataBundle/Perl/CPAN/Release.pm <==
# no code
## no critic: TestingAndDebugging::RequireUseStrict
package TableDataBundle::Perl::CPAN::Release;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2023-11-25'; # DATE
our $DIST = 'TableDataBundle-Perl-CPAN-Release'; # DIST
our $VERSION = '20231120.2'; # VERSION

1;
# ABSTRACT: Collection of TableData:: modules that contain CPAN releases data

__END__

=pod

=encoding UTF-8

=head1 NAME

TableDataBundle::Perl::CPAN::Release - Collection of TableData:: modules that contain CPAN releases data

=head1 VERSION

This document describes version 20231120.2 of TableDataBundle::Perl::CPAN::Release (from Perl distribution TableDataBundle-Perl-CPAN-Release), released on 2023-11-25.

=head1 DESCRIPTION

This distribution contains the following L<TableData>:: modules:

=over

=item * L<TableData::Perl::CPAN::Release::Static>

=item * L<TableData::Perl::CPAN::Release::Static::FromNewest>

=item * L<TableData::Perl::CPAN::Release::Static::GroupedDaily>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/TableDataBundle-Perl-CPAN-Release>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-TableDataBundle-Perl-CPAN-Release>.

=head1 SEE ALSO

L<TableData>

L<TableDataBundle::Perl::Release>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023, 2022, 2021 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataBundle-Perl-CPAN-Release>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut

==> TableDataBundle-Perl-CPAN-Release-20231120.3.tar.gz: TableDataBundle-Perl-CPAN-Release-20231120.3/lib/TableDataBundle/Perl/CPAN/Release.pm <==
# no code
## no critic: TestingAndDebugging::RequireUseStrict
package TableDataBundle::Perl::CPAN::Release;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2023-11-25'; # DATE
our $DIST = 'TableDataBundle-Perl-CPAN-Release'; # DIST
our $VERSION = '20231120.3'; # VERSION

1;
# ABSTRACT: Collection of TableData:: modules that contain CPAN releases data

__END__

=pod

=encoding UTF-8

=head1 NAME

TableDataBundle::Perl::CPAN::Release - Collection of TableData:: modules that contain CPAN releases data

=head1 VERSION

This document describes version 20231120.3 of TableDataBundle::Perl::CPAN::Release (from Perl distribution TableDataBundle-Perl-CPAN-Release), released on 2023-11-25.

=head1 DESCRIPTION

This distribution contains the following L<TableData>:: modules:

=over

=item * L<TableData::Perl::CPAN::Release::Static>

=item * L<TableData::Perl::CPAN::Release::Static::FromNewest>

=item * L<TableData::Perl::CPAN::Release::Static::GroupedDaily>

=item * L<TableData::Perl::CPAN::Release::Static::GroupedMonthly>

=item * L<TableData::Perl::CPAN::Release::Static::GroupedWeekly>

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/TableDataBundle-Perl-CPAN-Release>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-TableDataBundle-Perl-CPAN-Release>.

=head1 SEE ALSO

L<TableData>

L<TableDataBundle::Perl::Release>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023, 2022, 2021 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=TableDataBundle-Perl-CPAN-Release>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
